@@ -1,21 +1,27 @@
-from pathlib import Path
-import time
 import os
 import sys
+import time
+from pathlib import Path
 
-from naveen.experiment.config.experiment_group_parser import ExperimentGroupParser  # noqa: E501
-from naveen.experiment.experiment_runner import ExperimentRunner  # type: ignore # noqa: E501
+from naveen.experiment.config.experiment_group_parser import (  # noqa: E501
+    ExperimentGroupParser,
+)
+from naveen.experiment.experiment_runner import (  # type: ignore # noqa: E501
+    ExperimentRunner,
+)
 
 
 class ExperimentGroupRunner(object):
-
-    def __init__(self, config_path: str,  # type: ignore
-                 group_directory=None) -> None:  # type: ignore
+    def __init__(
+        self, config_path: str, group_directory=None  # type: ignore
+    ) -> None:  # type: ignore
         assert config_path.endswith("yaml") or config_path.endswith(
-            "yml"), "Experiment group config must be yaml"
+            "yml"
+        ), "Experiment group config must be yaml"
         self.group_config_path = config_path
         self.group_config = ExperimentGroupParser(
-            group_config_filename=self.group_config_path)
+            group_config_filename=self.group_config_path
+        )
         self.experiment_configs = self.group_config.parse_experiment_configs()
         group_name = self.group_config.get_group_name()
         if group_directory is None:
@@ -38,12 +44,14 @@ class ExperimentGroupRunner(object):
         self.prepare_path_to_results(path_to_results=path_to_results)
 
         for ex_no, experiment_config in enumerate(self.experiment_configs):
-            path_to_result = os.path.join(outputdir,
-                                          self.group_directory,
-                                          str(ex_no))
-            runner = ExperimentRunner(experiment_config,
-                                      package_name=package_name,
-                                      output_directory=path_to_result)
+            path_to_result = os.path.join(
+                outputdir, self.group_directory, str(ex_no)
+            )
+            runner = ExperimentRunner(
+                experiment_config,
+                package_name=package_name,
+                output_directory=path_to_result,
+            )
             runner.run()
 
 
