@@ -13,7 +13,7 @@ def get_logger(name: str = "logger",          # type: ignore
     ch = logging.StreamHandler()
     ch.setLevel(level)
     # create formatter and add it to the handlers
-    f: str = '%(asctime)s - %(levelname)s - %(message)s'
+    f: str = '%(asctime)s: %(pathname)s %(lineno)d - %(levelname)s - %(message)s'
     formatter = logging.Formatter(f,
                                   datefmt='%Y-%m-%d %H:%M:%S')
     ch.setFormatter(formatter)
